@@ -67,7 +67,7 @@ bokecc_patterns = [r'bokecc\.com/flash/pocle/player\.swf\?siteid=(.+?)&vid=(.{32
 recur_limit = 3
 
 
-def embed_download(url, output_dir = '.', merge = True, info_only = False ,**kwargs):
+def embed_download(url, output_dir = '.', merge = True, info_only = False, **kwargs):
     content = get_content(url, headers=fake_headers)
     found = False
     title = match1(content, '<title>([^<>]+)</title>')
@@ -75,43 +75,43 @@ def embed_download(url, output_dir = '.', merge = True, info_only = False ,**kwa
     vids = matchall(content, youku_embed_patterns)
     for vid in set(vids):
         found = True
-        youku_download_by_vid(vid, title=title, output_dir=output_dir, merge=merge, info_only=info_only)
+        youku_download_by_vid(vid, title=title, output_dir=output_dir, merge=merge, info_only=info_only, **kwargs)
 
     vids = matchall(content, tudou_embed_patterns)
     for vid in set(vids):
         found = True
-        tudou_download_by_id(vid, title=title, output_dir=output_dir, merge=merge, info_only=info_only)
+        tudou_download_by_id(vid, title=title, output_dir=output_dir, merge=merge, info_only=info_only, **kwargs)
 
     vids = matchall(content, yinyuetai_embed_patterns)
     for vid in vids:
         found = True
-        yinyuetai_download_by_id(vid, title=title, output_dir=output_dir, merge=merge, info_only=info_only)
+        yinyuetai_download_by_id(vid, title=title, output_dir=output_dir, merge=merge, info_only=info_only, **kwargs)
 
     vids = matchall(content, iqiyi_embed_patterns)
     for vid in vids:
         found = True
-        iqiyi_download_by_vid((vid[1], vid[0]), title=title, output_dir=output_dir, merge=merge, info_only=info_only)
+        iqiyi_download_by_vid((vid[1], vid[0]), title=title, output_dir=output_dir, merge=merge, info_only=info_only, **kwargs)
 
     urls = matchall(content, netease_embed_patterns)
     for url in urls:
         found = True
-        netease_download(url, output_dir=output_dir, merge=merge, info_only=info_only)
+        netease_download(url, output_dir=output_dir, merge=merge, info_only=info_only, **kwargs)
 
     urls = matchall(content, vimeo_embed_patters)
     for url in urls:
         found = True
-        vimeo_download_by_id(url, title=title, output_dir=output_dir, merge=merge, info_only=info_only, referer=url)
+        vimeo_download_by_id(url, title=title, output_dir=output_dir, merge=merge, info_only=info_only, referer=url, **kwargs)
 
     urls = matchall(content, dailymotion_embed_patterns)
     for url in urls:
         found = True
-        dailymotion_download(url, output_dir=output_dir, merge=merge, info_only=info_only)
+        dailymotion_download(url, output_dir=output_dir, merge=merge, info_only=info_only, **kwargs)
 
     aids = matchall(content, bilibili_embed_patterns)
     for aid in aids:
         found = True
         url = 'http://www.bilibili.com/video/av%s/' % aid
-        bilibili_download(url, output_dir=output_dir, merge=merge, info_only=info_only)
+        bilibili_download(url, output_dir=output_dir, merge=merge, info_only=info_only, **kwargs)
 
     iqiyi_urls = matchall(content, iqiyi_patterns)
     for url in iqiyi_urls:
